summaryrefslogtreecommitdiffstats
path: root/chrome/common/render_messages_params.h
diff options
context:
space:
mode:
authorjorlow@chromium.org <jorlow@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-09-17 11:27:26 +0000
committerjorlow@chromium.org <jorlow@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-09-17 11:27:26 +0000
commite7fd1980c7fbe92aea58b6d7256770d7be9ac621 (patch)
treea5ad99c8f423f086d79bd1612ebf517434650ea4 /chrome/common/render_messages_params.h
parent56d73f2dcb38999c4ec15f8a9c5236bf1ab5cf2d (diff)
downloadchromium_src-e7fd1980c7fbe92aea58b6d7256770d7be9ac621.zip
chromium_src-e7fd1980c7fbe92aea58b6d7256770d7be9ac621.tar.gz
chromium_src-e7fd1980c7fbe92aea58b6d7256770d7be9ac621.tar.bz2
Add IDBIndex plumbing (for IndexedDB).
BUG=none TEST=none Review URL: http://codereview.chromium.org/3442001 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@59780 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/common/render_messages_params.h')
-rw-r--r--chrome/common/render_messages_params.h36
1 files changed, 35 insertions, 1 deletions
diff --git a/chrome/common/render_messages_params.h b/chrome/common/render_messages_params.h
index aaa5bb0..4847695 100644
--- a/chrome/common/render_messages_params.h
+++ b/chrome/common/render_messages_params.h
@@ -652,6 +652,27 @@ struct ViewHostMsg_IDBDatabaseCreateObjectStore_Params {
int32 idb_database_id_;
};
+// Used to open both cursors and object cursors in IndexedDB.
+struct ViewHostMsg_IDBIndexOpenCursor_Params {
+ // The response should have this id.
+ int32 response_id_;
+
+ // The serialized left key.
+ IndexedDBKey left_key_;
+
+ // The serialized right key.
+ IndexedDBKey right_key_;
+
+ // The key flags.
+ int32 key_flags_;
+
+ // The direction of this cursor.
+ int32 direction_;
+
+ // The index the index belongs to.
+ int32 idb_index_id_;
+};
+
// Used to create an index.
struct ViewHostMsg_IDBObjectStoreCreateIndex_Params {
ViewHostMsg_IDBObjectStoreCreateIndex_Params();
@@ -680,15 +701,20 @@ struct ViewHostMsg_IDBObjectStoreOpenCursor_Params {
// The response should have this id.
int32 response_id_;
+
// The serialized left key.
IndexedDBKey left_key_;
+
// The serialized right key.
IndexedDBKey right_key_;
+
// The key flags.
int32 flags_;
+
// The direction of this cursor.
int32 direction_;
- // The object store the index belongs to.
+
+ // The object store the cursor belongs to.
int32 idb_object_store_id_;
};
@@ -1121,6 +1147,14 @@ struct ParamTraits<ViewHostMsg_IDBDatabaseCreateObjectStore_Params> {
};
template <>
+struct ParamTraits<ViewHostMsg_IDBIndexOpenCursor_Params> {
+ typedef ViewHostMsg_IDBIndexOpenCursor_Params param_type;
+ static void Write(Message* m, const param_type& p);
+ static bool Read(const Message* m, void** iter, param_type* p);
+ static void Log(const param_type& p, std::string* l);
+};
+
+template <>
struct ParamTraits<ViewHostMsg_IDBObjectStoreCreateIndex_Params> {
typedef ViewHostMsg_IDBObjectStoreCreateIndex_Params param_type;
static void Write(Message* m, const param_type& p);